@@ -11,7 +11,7 @@ from janrain.capture import Api, config, get_version, ApiResponseError, \
 class ApiArgumentParser(ArgumentParser):
     """
     A subclass of the argparse.ArgumentParser in the standard library. Adds the
-    common command-line options for authenticating with the Janrain API and 
+    common command-line options for authenticating with the Janrain API and
     allows for an janrain.capture.Api instance to be initialized using those
     credentials.
 
@@ -114,6 +114,13 @@ class ApiArgumentParser(ArgumentParser):
         else:
             return Api(credentials['apid_uri'], defaults)
 
+# flattens the parameters list if multiple -p is used
+def flatten_list(items):
+    if isinstance (items, list):
+        for i in items:
+            for s in flatten_list(i):
+                yield s
+    else: yield items
 
 def main():
     """
@@ -124,7 +131,9 @@ def main():
     parser.add_argument('api_call',
                         help="API endpoint expressed as a relative path " \
                              "(eg. /settings/get).")
-    parser.add_argument('-p', '--parameters', nargs='*',
+    # combining nargs='*' with append action produces a list of lists when
+    # using -p multiple times.
+    parser.add_argument('-p', '--parameters', action='append', nargs='*',
                         metavar="parameter=value",
                         help="parameters passed through to the API call")
     parser.add_argument('-v', '--version', action='version',
@@ -149,8 +158,7 @@ def main():
     # map list of parameters from command line into a dict for use as kwargs
     kwargs = {}
     if args.parameters:
-        kwargs = dict((key, value) for key, value in [s.split("=", 1)
-                      for s in args.parameters])
+        kwargs = dict(item.split("=", 1) for item in flatten_list(args.parameters))
 
     try:
         data = api.call(args.api_call, **kwargs)
